==> haskell-lsp0-test-0.11.0.7-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-BBHPmH6nL1Z7utIqv38yKu
key:                  lsp-test-0.11.0.7-BBHPmH6nL1Z7utIqv38yKu
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  033810eddbb34117d9af00b34e68df35
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-8LOjsh2NsXEBIQN9kYTjJ4:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-8LOjsh2NsXEBIQN9kYTjJ4:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-BBHPmH6nL1Z7utIqv38yKu
depends:
    Diff-0.4.0-F7vyJzYzam9CwrUJdg8bD2
    Glob-0.10.2-5LcO2uvmVkiLj5mcG3if5b
    aeson-1.5.6.0-6DdSUx8dbuIIjP00Zg5a6S
    aeson-pretty-0.8.9-AXFdNE1ZWy326pjreSMahS
    ansi-terminal-0.11-Kvq5JBN7BE16HA1JfrRBzw
    async-2.2.3-IdiNIvUG6Je7aMAPJeWE0D base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.2-AchFtERdZ63E4BSigaitpI
    conduit-parse-0.2.1.0-FQwiSBb3wjW1aztpQGH5Ct containers-0.6.4.1
    data-default-0.7.1.1-J3rzpkFy8Zd5Q7EBzVOXXF directory-1.3.6.1
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-1eCX2IDqABDKteqFYxgqFB
    lens-5.0.1-8m6Wsht5i4xJUQOyMfVULO mtl-2.2.2
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 process-1.6.11.0
    text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.14.0-FVdmWuNRiZiBPBGw5WvZRu

haddock-interfaces:   /usr/share/doc/haskell-lsp0-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp0-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp0-test-0.11.0.7-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-6pfI4PUKdpwJqfO43IQeuA
key:                  lsp-test-0.11.0.7-6pfI4PUKdpwJqfO43IQeuA
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  4bd3058bc25e91e821eb6e019da118b3
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-IKBzwVlVadxFMTWIMjonsz:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-IKBzwVlVadxFMTWIMjonsz:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-6pfI4PUKdpwJqfO43IQeuA
depends:
    Diff-0.4.0-F7vyJzYzam9CwrUJdg8bD2
    Glob-0.10.2-IjufxCfuL2iDDJXTBrJ8rg
    aeson-1.5.6.0-FZsVpvEwT8z4bK1D26EwAs
    aeson-pretty-0.8.9-4VpDxWXnDJA8Bu2hhX3Ado
    ansi-terminal-0.11-DOUngjGM5e9DBdxKKdJoVq
    async-2.2.3-9hcO3XZAP863cAPa5inA8N base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.2-G1HkDA3DXNW8qvzQqLFdeJ
    conduit-parse-0.2.1.0-3JvyuvijqHUFKSTUQKY59i containers-0.6.4.1
    data-default-0.7.1.1-5RJjHNv19ESJeD93LU2jRn directory-1.3.6.1
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-E3ZRoQpEMFxET11A5K2epv
    lens-5.0.1-E7Tul8EWHuqGCOW8gNOuPe mtl-2.2.2
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 process-1.6.11.0
    text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.14.0-7Twq3Q78XsnAV2eREMKYwX

haddock-interfaces:   /usr/share/doc/haskell-lsp0-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp0-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
